==> dart_code_metrics-4.13.0.tar.gz: lib/src/analyzers/lint_analyzer/rules/rules_list/binary_expression_operand_order/binary_expression_operand_order_rule.dart <==
// ignore_for_file: public_member_api_docs

import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/token.dart';
import 'package:analyzer/dart/ast/visitor.dart';

import '../../../../../utils/node_utils.dart';
import '../../../lint_utils.dart';
import '../../../models/internal_resolved_unit_result.dart';
import '../../../models/issue.dart';
import '../../../models/replacement.dart';
import '../../../models/severity.dart';
import '../../models/common_rule.dart';
import '../../rule_utils.dart';

part 'visitor.dart';

class BinaryExpressionOperandOrderRule extends CommonRule {
  static const String ruleId = 'binary-expression-operand-order';

  static const _warningMessage =
      'Prefer literals at RHS in binary expressions.';
  static const _correctionComment = 'Fix operator order.';

  BinaryExpressionOperandOrderRule([Map<String, Object> config = const {}])
      : super(
          id: ruleId,
          severity: readSeverity(config, Severity.style),
          excludes: readExcludes(config),
        );

  @override
  Iterable<Issue> check(InternalResolvedUnitResult source) {
    final visitor = _Visitor();

    source.unit.visitChildren(visitor);

    return visitor.binaryExpressions
        .map((lit) => createIssue(
              rule: this,
              location: nodeLocation(
                node: lit,
                source: source,
                withCommentOrMetadata: true,
              ),
              message: _warningMessage,
              replacement: Replacement(
                comment: _correctionComment,
                replacement:
                    '${lit.rightOperand} ${lit.operator} ${lit.leftOperand}',
              ),
            ))
        .toList(growable: false);
  }
}

==> dart_code_metrics-4.17.0-dev.1.tar.gz: lib/src/analyzers/lint_analyzer/rules/rules_list/binary_expression_operand_order/binary_expression_operand_order_rule.dart <==
// ignore_for_file: public_member_api_docs

import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/token.dart';
import 'package:analyzer/dart/ast/visitor.dart';

import '../../../../../utils/node_utils.dart';
import '../../../lint_utils.dart';
import '../../../models/internal_resolved_unit_result.dart';
import '../../../models/issue.dart';
import '../../../models/replacement.dart';
import '../../../models/severity.dart';
import '../../models/common_rule.dart';
import '../../rule_utils.dart';

part 'visitor.dart';

class BinaryExpressionOperandOrderRule extends CommonRule {
  static const String ruleId = 'binary-expression-operand-order';

  static const _warningMessage =
      'Prefer literals at RHS in binary expressions.';
  static const _correctionComment = 'Fix operator order.';

  BinaryExpressionOperandOrderRule([Map<String, Object> config = const {}])
      : super(
          id: ruleId,
          severity: readSeverity(config, Severity.style),
          excludes: readExcludes(config),
        );

  @override
  Iterable<Issue> check(InternalResolvedUnitResult source) {
    final visitor = _Visitor();

    source.unit.visitChildren(visitor);

    return visitor.binaryExpressions
        .map((lit) => createIssue(
              rule: this,
              location: nodeLocation(node: lit, source: source),
              message: _warningMessage,
              replacement: Replacement(
                comment: _correctionComment,
                replacement:
                    '${lit.rightOperand} ${lit.operator} ${lit.leftOperand}',
              ),
            ))
        .toList(growable: false);
  }
}
